#!/bin/bash
type=$1
name=$2

function nameInput() {
  echo "What is the Component name?"
  read name
}

function typeInput() {
  options=("atoms" "molecules" "organisms" "pages" "templates")
  select opt in "${options[@]}"
  do
      case $opt in
          "atoms")
              printf "You chose $opt\n\n"
              type="$opt"
              break
              ;;
          "molecules")
              printf "You chose $opt\n\n"
              type="$opt"
              break
              ;;
          "organisms")
              printf "You chose $opt\n\n"
              type="$opt"
              break
              ;;
          "pages")
              printf "You chose $opt\n\n"
              type="$opt"
              break
              ;;
          "templates")
              printf "You chose $opt\n\n"
              type="$opt"
              break
              ;;
          *) echo invalid option;;
      esac
  done
  nameInput
}

if [[ $# = 0 ]]; then
  printf "No type was inputed, please select a Component type:\n\n"
  typeInput
elif [[ "$type" = "atoms" ]]; then
  printf "Type is: $type\n\n"
elif [[ "$type" = "molecules" ]]; then
  printf "Type is: $type\n\n"
elif [[ "$type" = "organisms" ]]; then
  printf "Type is: $type\n\n"
elif [[ "$type" = "pages" ]]; then
  printf "Type is: $type\n\n"
elif [[ "$type" = "templates" ]]; then
  printf "Type is: $type\n\n"
else
  printf "A wrong type was inputed, please select a Component type:\n\n"
  typeInput
fi

if [[ "$name" = "" ]]; then
  printf "No 'Name' was inputed\n\n"
  nameInput
fi

name="$(tr '[:lower:]' '[:upper:]' <<< ${name:0:1})${name:1}"

cd src/components
printf "export { default as $name } from './$type/$name'\n" >> index.js
cd $type
mkdir $name
cd $name

printf "Name is: $name\n\n"

echo "Generating css file..."
printf "" > index.scss

echo "Generating test file..."
printf "\
import React from 'react'\n\
import ReactDOM from 'react-dom'\n\
import Component from '.'\n\
\n\
import MockedComponentHOC from 'MockedComponentHOC'\n\
\n\
const MockedComponent = MockedComponentHOC(Component)\n\
it('renders without crashing', () => {\n\
  const div = document.createElement('div')\n\
  ReactDOM.render(<MockedComponent/>, div)\n\
})" > index.test.js

echo "Generating stories file..."
printf "\
import React from 'react'
import { storiesOf } from '@storybook/react'
import Component from '.'
import MockedComponentHOC from 'MockedComponentHOC'

const stories = [
    {
        name:'Simple ${name}',
        props: {}
    },
]

const MockedComponent = MockedComponentHOC(Component)
const instanceOfStories = storiesOf('${name}', module)
stories.map(v => instanceOfStories.add(v.name, () => <MockedComponent {...v.props} />))" > index.stories.js

echo "Generating component file..."
printf "\
import React, { Component } from 'react'\n\
import './index.scss'\n\
import { observer } from 'mobx-react'\n\
//import PropTypes from 'prop-types'\n\
//import classNames from 'classnames'\n\
\n\
@observer\n\
class ${name} extends Component {\n\
  render() {\n\
    return (\n\
      <div>\n\
        ${name}
      </div>\n\
    )\n\
  }\n\
}\n\
\n\
${name}.propTypes = {}\n\
\n\
${name}.defaultProps = {}\n\
\n\
${name}.displayName = '${name}'\n\
\n\
export default ${name}" > index.js

sleep 1
