import React from 'react'
import ReactDOM from 'react-dom'
import createBrowserHistory from 'history/createBrowserHistory'
import { Provider } from 'mobx-react'
import { RouterStore, syncHistoryWithStore } from 'mobx-react-router'
import { Router } from 'react-router-dom'
import * as stores from 'stores'
import AppRouter from './AppRouter'

import './index.css'
import registerServiceWorker from './registerServiceWorker'
import { AppContainer } from 'react-hot-loader'

const browserHistory = createBrowserHistory()
const routingStore = new RouterStore()
const history = syncHistoryWithStore(browserHistory, routingStore)

const render = Component => {
  ReactDOM.render(
    <AppContainer>
      <Router history={history}>
        <Provider {...stores} routingStore={routingStore}>
          <Component />
        </Provider>
      </Router>
    </AppContainer>,
    document.getElementById('root')
  )
}

render(AppRouter)

if (module.hot) {
  module.hot.accept('./AppRouter', () => {
    render(AppRouter)
  })
}

registerServiceWorker()
